@@ -33,6 +33,9 @@ class Command(BaseCommand):
             app_prefs.AlertEnable = 'Enable'
             app_prefs.ApplicationURL = get_notification_url()
             app_prefs.ApplicationEnable = 'Enable'
+            # these fields are optional but suds sends empty keys for them if you don't give values
+            app_prefs.DeviceType = 'Platform'
+            app_prefs.NotificationPayloadType - 'eBLSchemaSOAP'
 
             user_prefs = client.sudsclient.factory.create('NotificationEnableArrayType')
             for arg in args:
